#ifndef __LED_H__
#define __LED_H__

#ifdef __cplusplus
 extern "C" {
#endif

#include "stm32f4xx.h"

#define PORT_LED (GPIOC)
#define LED1     (GPIO_Pin_4)
#define LED2     (GPIO_Pin_5)

void led_init(uint16_t led);
void led_off(uint16_t led);
void led_on(uint16_t led);
void led_toggle(uint16_t led);
void led_delay_ms(uint16_t ms);
void led_indicate_error(void);
void led_deinit(void);

#ifdef __cplusplus
}
#endif

#endif /* __LED_H__ */
